Trait std::str::FromStrStable
[-] [+]
[src]
pub trait FromStr {
type Err;
fn from_str(s: &str) -> Result<Self, Self::Err>;
}A trait to abstract the idea of creating a new instance of a type from a string.
Associated Types
Required Methods
fn from_str(s: &str) -> Result<Self, Self::Err>
Parses a string s to return an optional value of this type. If the
string is ill-formatted, the None is returned.
Implementors
impl FromStr for f32impl FromStr for f64impl FromStr for isizeimpl FromStr for i8impl FromStr for i16impl FromStr for i32impl FromStr for i64impl FromStr for usizeimpl FromStr for u8impl FromStr for u16impl FromStr for u32impl FromStr for u64impl FromStr for boolimpl FromStr for Stringimpl FromStr for IpAddrimpl FromStr for Ipv4Addrimpl FromStr for Ipv6Addrimpl FromStr for SocketAddr